OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Неуспешен опит за запис в \"config\" папката!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Това може да бъде решено единствено като разрешиш на уеб сървъра да пише в config папката.",
    "See %s" : "Виж %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Това обикновено може да бъде оправено като %s даде разрешение на уеб сървъра да записва в config папката %s.",
    "Sample configuration detected" : "Открита е примерна конфигурация",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Усетено беше че примерната конфигурация е копирана. Това може да развли инсталацията ти и не се поддържа. Моля, прочети документацията преди да правиш промени на config.php",
    "PHP %s or higher is required." : "Изисква се PHP %s или по-нова.",
    "PHP with a version lower than %s is required." : "Необходим е PHP с версия по-ниска от %s.",
    "Following databases are supported: %s" : "Следните бази данни са поддържани: %s",
    "The command line tool %s could not be found" : "Конзолната команда %s не може да бъде намерена",
    "The library %s is not available." : "Библиотеката %s не е налична",
    "Library %s with a version higher than %s is required - available version %s." : "Необходима е библиотеката %s с версия по-висока от %s - налична версия %s. ",
    "Library %s with a version lower than %s is required - available version %s." : "Необходима е библиотеката %s с версия по-ниска от %s - налична версия %s. ",
    "Following platforms are supported: %s" : "Поддържани са следните платформи: %s",
    "ownCloud %s or higher is required." : "Необходим е ownCloud %s или по-висока версия.",
    "Help" : "Помощ",
    "Personal" : "Лични",
    "Users" : "Потребители",
    "Admin" : "Админ",
    "Recommended" : "Препоръчано",
    "No app name specified" : "Не е зададено име на преложението",
    "Unknown filetype" : "Непознат тип файл.",
    "Invalid image" : "Невалидно изображение.",
    "today" : "днес",
    "yesterday" : "вчера",
    "_%n day ago_::_%n days ago_" : ["преди %n ден","преди %n дни"],
    "last month" : "миналия месец",
    "last year" : "миналата година",
    "_%n year ago_::_%n years ago_" : ["преди %n година","преди %n години"],
    "seconds ago" : "преди секунди",
    "web services under your control" : "уеб услуги под твой контрол",
    "File name contains at least one invalid character" : "Името на файла съдържа поне един невалиден символ",
    "App directory already exists" : "Папката на приложението вече съществува.",
    "Can't create app folder. Please fix permissions. %s" : "Неуспешно създаване на папката за приложението. Моля, оправете разрешенията. %s",
    "No source specified when installing app" : "Не е зададен източник при инсталацията на приложението.",
    "No href specified when installing app from http" : "Липсва съдържанието на връзката за инсталиране на приложението",
    "No path specified when installing app from local file" : "Не е зададен пътя до локалния файл за инсталиране на приложението.",
    "Archives of type %s are not supported" : "Архиви от тип %s не се подържат",
    "Failed to open archive when installing app" : "Неуспешно отваряне на архив по времен на инсталацията на приложението.",
    "App does not provide an info.xml file" : "Приложенението не добавило info.xml",
    "App can't be installed because of not allowed code in the App" : "Приложението няма да бъде инсталирано, защото използва неразрешен код.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Приложението няма да бъде инсталирано, защото не е съвместимо с текущата версия на ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Приложението няма да бъде инсталирано, защото съдържа <shipped>true</shipped>, който таг не е разрешен за не ship-нати приложения.",
    "Application is not enabled" : "Приложението не е включено",
    "Authentication error" : "Проблем с идентификацията",
    "Token expired. Please reload page." : "Изтекла сесия. Моля, презареди страницата.",
    "Unknown user" : "Непознат потребител",
    "%s enter the database username." : "%s въведи потребителско име за базата данни.",
    "%s enter the database name." : "%s въведи име на базата данни.",
    "%s you may not use dots in the database name" : "%s, не може да ползваш точки в името на базата данни.",
    "Oracle connection could not be established" : "Oracle връзка не можа да се осъществи.",
    "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
    "DB Error: \"%s\"" : "Грешка в базата данни: \"%s\".",
    "Offending command was: \"%s\"" : "Проблемната команда беше: \"%s\".",
    "You need to enter either an existing account or the administrator." : "Необходимо е да въведеш съществуващ профил или като администратор.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Проблемната команда беше: \"%s\", име: %s, парола: %s.",
    "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
    "Set an admin username." : "Задай потребителско име за администратор.",
    "Set an admin password." : "Задай парола за администратор.",
    "Can't create or write into the data directory %s" : "Неуспешно създаване или записване в \"data\" папката %s",
    "%s shared »%s« with you" : "%s сподели »%s« с теб",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Неуспешно споделяне на %s  , защото сървъра не позволява споделяне от тип $i.",
    "Sharing %s failed, because the file does not exist" : "Неуспешно споделяне на %s, защото файлът не съществува.",
    "You are not allowed to share %s" : "Не ти е разрешено да споделяш %s.",
    "Sharing %s failed, because the user %s does not exist" : "Неуспешно споделяне на %s, защото потребител %s не съществува.",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Неуспешно споделяне на %s, защото %s не е член никоя от групите, в които %s членува.",
    "Sharing %s failed, because this item is already shared with %s" : "Неуспешно споделяне на %s, защото това съдържание е вече споделено с %s.",
    "Sharing %s failed, because the group %s does not exist" : "Неупешно споделяне на %s, защото групата %s не съществува.",
    "Sharing %s failed, because %s is not a member of the group %s" : "Неуспешно споделяне на %s, защото %s не е член на групата %s.",
    "You need to provide a password to create a public link, only protected links are allowed" : "Трябва да зададеш парола, за да създадеш общодостъпен линк за споделяне, само защитени с пароли линкове са разрешени.",
    "Sharing %s failed, because sharing with links is not allowed" : "Неуспешно споделяне на %s, защото споделянето посредством връзки не е разрешено.",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Неуспешно споделяне на на %s, не може бъде намерено %s. Може би сървъра в момента е недостъпен.",
    "Share type %s is not valid for %s" : "Споделянето на тип %s не валидно за %s.",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Неуспешна промяна на правата за достъп за %s, защото промените надвишават правата на достъп дадени на %s.",
    "Setting permissions for %s failed, because the item was not found" : "Неуспешна промяна на правата за достъп за %s, защото съдържанието не е открито.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Неуспешно задаване на дата на изтичане. Споделни папки или файлове не могат да изтичат по-късно от %s след като са били споделени",
    "Cannot set expiration date. Expiration date is in the past" : "Неуспешно задаване на дата на изтичане. Датата на изтичане е в миналото",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
    "Sharing backend %s not found" : "Споделянето на сървърния %s не е открито.",
    "Sharing backend for %s not found" : "Споделянето на сървъра за %s не е открито.",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Неуспешно споделяне на %s, защото промените надвишават правата на достъп дадени на %s.",
    "Sharing %s failed, because resharing is not allowed" : "Неуспешно споделяне на %s, защото повторно споделяне не е разрешено.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Неуспешно споделяне на %s, защото не е открит първоизточникът на %s, за да бъде споделяне по сървъра.",
    "Sharing %s failed, because the file could not be found in the file cache" : "Неуспешно споделяне на %s, защото файлът не може да бъде намерен в кеша.",
    "Could not find category \"%s\"" : "Невъзможно откриване на категорията \"%s\".",
    "Apps" : "Приложения",
    "A valid username must be provided" : "Валидно потребителско име трябва да бъде зададено.",
    "A valid password must be provided" : "Валидна парола трябва да бъде зададена.",
    "The username is already being used" : "Това потребителско име е вече заето.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Липсват инсталирани драйвери за бази данни(sqlite, mysql или postgresql).",
    "Cannot write into \"config\" directory" : "Неуспешен опит за запис в \"config\" папката.",
    "Cannot write into \"apps\" directory" : "Неуспешен опит за запис в \"apps\" папката.",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Това обикновено може да бъде оправено като %s даде разрешение на уеб сървъра да записва в app папката %s или като изключи магазина за приложения в config файла.",
    "Cannot create \"data\" directory (%s)" : "Неуспешен опит за създаване на \"data\" папката (%s).",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Това обикновено може да бъде оправено като <a href=\"%s\" target=\"_blank\">дадеш разрешение на уеб сървъра да записва в root  папката</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Правата за достъп обикновено могат да бъдат оправени като %s даде разрешение на уеб сървъра да пише в root папката %s.",
    "Setting locale to %s failed" : "Неуспешно задаване на %s като настройка език-държава.",
    "Please install one of these locales on your system and restart your webserver." : "Моля, инсталирай едно от следните език-държава на сървъра и рестартирай уеб сървъра.",
    "Please ask your server administrator to install the module." : "Моля, поискай твоят администратор да инсталира модула.",
    "PHP module %s not installed." : "PHP модулът %s не е инсталиран.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на cache/accelerator като Zend OPache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP модулите са инсталирани, но все още се обявяват като липсващи?",
    "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
    "PostgreSQL >= 9 required" : "Изисква се PostgreSQL >= 9",
    "Please upgrade your database version" : "Моля, обнови базата данни.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, промени правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители.",
    "Data directory (%s) is readable by other users" : "Data папката (%s) може да бъде разгледана от други потребители",
    "Data directory (%s) is invalid" : "Data папката (%s) e невалидна",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Моля, увери се, че data папката съдържа файл \".ocdata\" в себе си.",
    "Could not obtain lock type %d on \"%s\"." : "Неуспешен опит за ексклузивен достъп от типa %d върху \"%s\".",
    "Storage not available" : "Липсва дисковото устройство."
},
"nplurals=2; plural=(n != 1);");
